#
# spec file for package libcryptui
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libcryptui
Version:        3.12.2
Release:        11.3
# FIXME: find out why building introspection support for this package requires libtool
Summary:        Library for prompting for PGP keys
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Security
URL:            http://projects.gnome.org/seahorse/
Source:         http://download.gnome.org/sources/libcryptui/3.12/%{name}-%{version}.tar.xz
BuildRequires:  gobject-introspection-devel
BuildRequires:  gpg2
BuildRequires:  gpgme-devel
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(gthread-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0.0
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(sm)

%description
Libcryptui is a library used for prompting for PGP keys.

%package -n libcryptui0
Summary:        Library for prompting for PGP keys
License:        LGPL-2.1-or-later
Group:          System/Libraries
# Need some schema from gnome-keyring
Requires:       %{name}-data
Requires:       gnome-keyring
# The library talks to seahorse-daemon
Recommends:     seahorse-daemon
# To make lang package installable
Provides:       %{name} = %{version}

%description -n libcryptui0
Libcryptui is a library used for prompting for PGP keys.

%package -n typelib-1_0-CryptUI-0_0
Summary:        Introspection bindings for libcryptui, a PGP key prompting library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n typelib-1_0-CryptUI-0_0
Libcryptui is a library used for prompting for PGP keys.

This package provides the GObject Introspection bindings for
libcryptui.

%package -n libcryptui-data
Summary:        Data files for libcryptui, a PGP key prompting library
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
%glib2_gsettings_schema_requires

%description -n libcryptui-data
Libcryptui is a library used for prompting for PGP keys.

%package -n seahorse-daemon
Summary:        Daemon for PGP prompting by libcryptui
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
Requires:       %{name}-data

%description -n seahorse-daemon
Libcryptui is a library used for prompting for PGP keys.

%package devel
Summary:        Development files for libcryptui, a PGP key prompting library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
Requires:       libcryptui0 = %{version}
Requires:       typelib-1_0-CryptUI-0_0 = %{version}

%description devel
Libcryptui is a library used for prompting for PGP keys.

%lang_package

%prep
%setup -q
sed -i "s:1.2 1.4 2.0:1.2 1.4 2.0 2.1 2.2 2.3 2.4 2.5:" configure

%build
%configure \
        --disable-static
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang cryptui %{?no_lang_C}

%post -n libcryptui0 -p /sbin/ldconfig
%postun -n libcryptui0 -p /sbin/ldconfig

%post -n libcryptui-data
%glib2_gsettings_schema_post

%postun -n libcryptui-data
%glib2_gsettings_schema_postun

%files -n libcryptui0
%doc AUTHORS ChangeLog COPYING-LIBCRYPTUI NEWS README
%{_libdir}/libcryptui.so.*

%files -n typelib-1_0-CryptUI-0_0
%{_libdir}/girepository-1.0/CryptUI-0.0.typelib

%files -n libcryptui-data
# Own the directory since we can't depend on gconf providing them
%dir %{_datadir}/GConf
%dir %{_datadir}/GConf/gsettings
%{_datadir}/GConf/gsettings/org.gnome.seahorse.recipients.convert
%{_datadir}/glib-2.0/schemas/org.gnome.seahorse.recipients.gschema.xml

%files -n seahorse-daemon
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/seahorse-daemon
%{_datadir}/dbus-1/services/org.gnome.seahorse.service
%{_datadir}/cryptui/
%{_datadir}/pixmaps/cryptui/
%{_mandir}/man1/seahorse-daemon.1%{ext_man}

%files lang -f cryptui.lang

%files devel
%{_includedir}/libcryptui/
%{_libdir}/pkgconfig/cryptui-0.0.pc
%{_libdir}/libcryptui.so
%{_datadir}/gir-1.0/CryptUI-0.0.gir
%doc %{_datadir}/gtk-doc/html/libcryptui/

%changelog
* Thu Oct 24 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add GnuPG 2.5.x to the list of supported GnuPG versions.
* Mon Jan  9 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add GnuPG 2.4.x to the list of supported GnuPG versions.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Tue Aug 31 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add GnuPG 2.3.x to the list of supported GnuPG versions.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Mar  5 2018 jengelh@inai.de
- Update summaries.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Aug 30 2017 dimstar@opensuse.org
- Add 2.2 to the list of accepted GPG versions.
* Tue Dec 16 2014 dimstar@opensuse.org
- Inject version 2.1 as acceptable gpg version into configure:
  GPG 2.1 is verified to be compatible and supported.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Build fix on FreeBSD (bgo#727196).
  + Updated translations.
* Thu Oct 17 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Build fix.
  + Updated translations.
* Mon Aug 26 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Add symmetric encryption as a choice in "choose recipients"
    dialog (bgo#325803).
  + Add support for symmetric encryption (bgo#699161).
  + Add cryptui_need_to_get_keys_or_symmetric() (bgo#325803).
  + Avoid repeating the self encryption key in
    cryptui_key_chooser_ge (bgo#701987).
  + Fix warning on startup about missing seahorse-daemon.desktop
    file.
  + Set the source on UID objects.
  + Build fixes.
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + no changes from previous release.
* Fri Mar 15 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Stable release: no changes from previous release.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Updated translations.
* Wed Jul 18 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Make the default key chooser window size bigger
  + Bump dependency versions, and fix deprecetions
  + Documentation fixes.
- Add pkgconfig(gthread-2.0) BuildRequires so it can be versioned.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Build fixes
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + No changes.
* Fri Mar  9 2012 dimstar@opensuse.org
- Update to version 3.3.91:
  + Add dependency on libSM and libICE, needed for XSMP client
- No packaging change: we already have those BuildRequires.
* Sun Feb 19 2012 dimstar@opensuse.org
- Add pkgconfig(ice) and pkgconfig(sm) BuildRequires: they used to
  be pulled in by something else, but the relayout of xorg-x11
  packages changed that.
* Sun Feb  5 2012 dimstar@opensuse.org
- Update to version 3.3.5:
  + Updated translations.
* Wed Dec  7 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-CryptUI-0_0 subpackage.
- Add typelib-1_0-CryptUI-0_0 Requires to devel subpackage.
* Sun Dec  4 2011 dimstar@opensuse.org
- Add libtool BuildRequires to fix build (not entirely sure here
  why it's needed though).
- Change License tags to spdx identifier.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 3.2.2:
  + Fix GSettings conversion
* Fri Sep 30 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
- Changes from version 3.1.91:
  + Port to GSettings instead of GConf
  + Build fixes
- Remove gnome-doc-utils-devel BuildRequires: the unneeded
  dependency was removed upstream.
- Remove pkgconfig(gconf-2.0) BuildRequires: port to GSettings.
- Split the GSettings schema in a libcryptui-data subpackage, and
  add a Requires for it to libcryptui0 and seahorse-daemon.
- Replace all the gconf packaging machinery with the gsettings one.
- Drop libcryptui-no-seahorse-conflict.patch: fixed upstream.
- Remove call to autoreconf, as it was only needed for the patch
  above.
* Thu Jul 28 2011 vuntz@opensuse.org
- Add libcryptui-no-seahorse-conflict.patch: this renames some
  files to avoid conflicts with seahorse on the filesystem.
  Add call to autoreconf, needed by the patch.
* Mon Jul 25 2011 vuntz@opensuse.org
- Initial package (version 3.1.4); libcryptui was split from
  seahorse upstream.
